@@ -95,7 +95,7 @@ else:
     input_stream = io.TextIOWrapper(sys.stdin.buffer, encoding='utf-8')
     output_stream = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8')
 
-__version__ = '0.2.9'
+__version__ = '0.3.0'
 
 try:
     # Jupyter >= 4
@@ -108,6 +108,9 @@ except ImportError:
         # IPython < 3
         from IPython.nbformat import current
 
+        # Dummy value, ignored anyway
+        NO_CONVERT = None
+
         def read(f, as_version):
             return current.read(f, 'json')
 
@@ -143,8 +146,9 @@ def strip_output(nb):
         for output_style in ['collapsed', 'scrolled']:
             if output_style in cell.metadata:
                 cell.metadata[output_style] = False
-        for useless_metadata in ['ExecuteTime']:
-            cell.metadata.pop(useless_metadata, None)
+        if 'metadata' in cell:
+            for field in ['collapsed', 'scrolled', 'ExecuteTime']:
+                cell.metadata.pop(field, None)
     return nb
 
 
@@ -157,7 +161,7 @@ def install(attrfile=None):
     except CalledProcessError:
         print('Installation failed: not a git repository!', file=sys.stderr)
         sys.exit(1)
-    check_call(['git', 'config', 'filter.nbstripout.clean', '%s %s' %
+    check_call(['git', 'config', 'filter.nbstripout.clean', '"%s" "%s"' %
                (sys.executable.replace('\\', '/'),
                 path.abspath(__file__).replace('\\', '/'))])
     check_call(['git', 'config', 'filter.nbstripout.smudge', 'cat'])
